@@ -158,7 +158,7 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 			global led_vis
 			global gr
 			def menu_timer(a,b):
-				if not(self.shutter_button_iface.GetProperty("button.state.value")):
+				if not(self.shutter_button_iface.GetProperty("button.state.value"))and(self.proximity_iface.GetProperty("button.state.value")):
 					global gr,menu_vis
 					if a==gr:
 						if menu_vis==0:
